from .utils import (
    detect_language,
    get_available_language_codes,
    get_available_language_packs,
    get_translit_function,
    slugify,
    translit,
)

__title__ = 'transliterate'
__version__ = '1.10.2'
__author__ = 'Artur Barseghyan'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'detect_language',
    'get_available_language_codes',
    'get_available_language_packs',
    'get_translit_function',
    'slugify',
    'translit',
)
