# -*- coding: utf-8 -*-

mapping = (
    u"abvgdđežzijklmnoprstćufhcčšABVGDĐEŽZIJKLMNOPRSTĆUFHCČŠ",
    u"абвгдђежзијклмнопрстћуфхцчшАБВГДЂЕЖЗИЈКЛМНОПРСТЋУФХЦЧШ",
)

reversed_specific_mapping = (
    u"",
)

pre_processor_mapping = {
    u"lj": u"љ",
    u"nj": u"њ",
    u"dž": u"џ",
    u"Lj": u"Љ",
    u"Nj": u"Њ",
    u"Dž": u"Џ",
}
