# -*- coding: utf-8 -*-

mapping = (
    u"ABGDEVZTIKLMNOPJRSTUFQYCXHabgdevztiklmnoprsufqycxjhw",
    u"აბგდევზთიკლმნოპჟრსტუფქყცხჰაბგდევზთიკლმნოპრსუფქყცხჯჰწ",
)


pre_processor_mapping = {
    u"zh": u"ჟ",
    u"gh": u"ღ",
    u"sh": u"შ",
    u"ch": u"ჩ",
    u"ch'": u"ჭ",
    u"dz": u"ძ",
    u"ts": u"წ",
    u"kh": u"ხ",
}
