from .default import *

__title__ = 'transliterate.contrib.languages.hy.data'
__author__ = 'Artur Barseghyan'
__copyright__ = '2013-2018 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
# __all__ = ('ArmenianLanguagePack',)
